
# Slot: values_from


the identifier of a "value set" -- a set of identifiers that form the possible values for the range of a slot

URI: [linkml:values_from](https://w3id.org/linkml/values_from)


## Domain and Range

[Definition](Definition.md) &#8594;  <sub>0..\*</sub> [Uriorcurie](Uriorcurie.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [SlotDefinition](SlotDefinition.md)
